@@ -135,10 +135,13 @@ i_img *i_img_pal_new_low(i_img *im, int x, int y, int channels, int maxpal) {
 /*
 =item i_img_pal_new(x, y, channels, maxpal)
 
-=category Image creation
+=category Image creation/destruction
+=synopsis i_img *img = i_img_pal_new(width, height, channels, max_palette_size)
 
 Creates a new paletted image of the supplied dimensions.
 
+I<maxpal> is the maximum palette size and should normally be 256.
+
 Returns a new image or NULL on failure.
 
 =cut
@@ -423,6 +426,11 @@ static int i_gsamp_p(i_img *im, int l, int r, int y, i_sample_t *samps,
       }
     }
     else {
+      if (chan_count <= 0 || chan_count > im->channels) {
+	i_push_errorf(0, "chan_count %d out of range, must be >0, <= channels", 
+		      chan_count);
+	return 0;
+      }
       for (i = 0; i < w; ++i) {
         i_palidx which = *data++;
         if (which < palsize) {
